@@ -20,6 +20,17 @@ func (p *Pos) String() string {
 	return fmt.Sprintf("line:%d,col:%d", p.Line, p.Col)
 }
 
+// IsBefore returns if the position is before the other position. If they are equal, this function returns false.
+func (p *Pos) IsBefore(other *Pos) bool {
+	if p.Line < other.Line {
+		return true
+	}
+	if p.Line > other.Line {
+		return false
+	}
+	return p.Col < other.Col
+}
+
 // String represents generic string value in YAML file with position.
 type String struct {
 	// Value is a raw value of the string.
@@ -66,6 +77,21 @@ type Event interface {
 	EventName() string
 }
 
+// WebhookEventFilter is a filter for Webhook events such as 'branches', 'paths-ignore', ...
+// Webhook events are filtered by those filters. Some filters are exclusive.
+// https://docs.github.com/en/actions/using-workflows/workflow-syntax-for-github-actions#using-filters
+type WebhookEventFilter struct {
+	// Name is a name of filter such like 'branches', 'tags'
+	Name *String
+	// Values is a list of filter values.
+	Values []*String
+}
+
+// IsEmpty returns true when it has no value. This may mean the WebhookEventFilter instance itself is nil.
+func (f *WebhookEventFilter) IsEmpty() bool {
+	return f == nil || len(f.Values) == 0
+}
+
 // WebhookEvent represents event type based on webhook events.
 // Some events can't have 'types' field. Only 'push' and 'pull' events can have 'tags', 'tags-ignore',
 // 'paths' and 'paths-ignore' fields. Only 'workflow_run' event can have 'workflows' field.
@@ -76,18 +102,18 @@ type WebhookEvent struct {
 	// Types is list of types of the webhook event. Only the types enumerated here will trigger
 	// the workflow.
 	Types []*String
-	// Branches is list of branch filters to choose branches.
-	Branches []*String
-	// BranchesIgnore is list of branch filters to reject some branches.
-	BranchesIgnore []*String
-	// Tags is list of tag filters to choose tags.
-	Tags []*String
-	// TagsIgnore is list of tag filters to reject some tags.
-	TagsIgnore []*String
-	// Paths is list of path filters to choose file paths.
-	Paths []*String
-	// PathsIgnore is list of path filters to reject some file paths.
-	PathsIgnore []*String
+	// Branches is 'branches' filter. This value is nil when it is omitted.
+	Branches *WebhookEventFilter
+	// BranchesIgnore is 'branches-ignore' filter. This value is nil when it is omitted.
+	BranchesIgnore *WebhookEventFilter
+	// Tags is 'tags' filter. This value is nil when it is omitted.
+	Tags *WebhookEventFilter
+	// TagsIgnore is 'tags-ignore' filter. This value is nil when it is omitted.
+	TagsIgnore *WebhookEventFilter
+	// Paths is 'paths' filter. This value is nil when it is omitted.
+	Paths *WebhookEventFilter
+	// PathsIgnore is 'paths-ignore' filter. This value is nil when it is omitted.
+	PathsIgnore *WebhookEventFilter
 	// Workflows is list of workflow names which are triggered by 'workflow_run' event.
 	Workflows []*String
 	// Pos is a position in source.
@@ -198,13 +224,20 @@ type WorkflowCallEventInput struct {
 	Description *String
 	// Default is a default value of the input. Nil means no default value.
 	Default *String
-	// Required represents if the input is required or optional. When this value is nil, it means optional.
+	// Required represents if the input is required or optional. When this value is nil, it was not explicitly specified.
+	// In the case the default value is 'not required'.
 	Required *Bool
 	// Type of the input, which must be one of 'boolean', 'number' or 'string'. This property is required.
 	// https://docs.github.com/en/actions/learn-github-actions/workflow-syntax-for-github-actions#onworkflow_callinput_idtype
 	Type WorkflowCallEventInputType
 }
 
+// IsRequired returns if the input is marked as required or not.
+// require
+func (i *WorkflowCallEventInput) IsRequired() bool {
+	return i.Required != nil && i.Required.Value
+}
+
 // WorkflowCallEventSecret is a secret configuration of workflow_call event.
 // https://docs.github.com/en/actions/learn-github-actions/workflow-syntax-for-github-actions#onworkflow_callsecrets
 type WorkflowCallEventSecret struct {
